@@ -1,5 +1,5 @@
 package App::ansifold;
-our $VERSION = "1.17";
+our $VERSION = "1.18";
 
 use v5.14;
 use warnings;
@@ -202,11 +202,7 @@ sub doit {
 	   expand tabstyle tabstop tabhead tabspace discard)
 	);
 
-    my $separator = do {
-	$app->separate =~ s{ ( \\ (.) ) }{
-	    { '\\' => '\\', n => "\n" }->{$2} // $1
-	}gexr;
-    };
+    my $separator = eval sprintf qq["%s"], $app->separate;
 
     my @index = @{$app->width_index};
 
@@ -236,8 +232,8 @@ sub doit {
 }
 
 sub fill_paragraph {
-    s/(?<=\p{InFullwidth})\n(?=\p{InFullwidth})//g;
-    s/[ ]*\n[ ]*/ /g;
+    s/(?<=\p{InFullwidth})\R(?=\p{InFullwidth})//g;
+    s/[ ]*\R[ ]*/ /g;
 }
 
 sub terminal_width {
